'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _require = require('lodash'),
    map = _require.map,
    isArray = _require.isArray;

var validate = require('../validate');
var throwing = require('../util/throwing');
var ValidationError = require('../error/ValidationError');
var isValidationError = require('../util/isValidationError');

/**
 * Validate that all the given rules pass
 *
 * @param rules
 * @param {string|null} [error = null] Optionally "override" the ValidationError message
 *
 * @returns {function}
 */
module.exports = function (rules) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref$error = _ref.error,
        error = _ref$error === undefined ? null : _ref$error;

    if (!isArray(rules)) throw new TypeError('Rules should be an array, ' + (typeof rules === 'undefined' ? 'undefined' : _typeof(rules)) + ' given.');

    return function () {
        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return Promise.all(map(rules, function (rule) {
            return throwing(function () {
                return validate.apply(undefined, [rule].concat(args));
            });
        })).then(function () {
            return null;
        }, function (e) {
            throw isValidationError(e) && error ? new ValidationError(error) : e;
        });
    };
};