'use strict';

var pTry = require('./../util/pTry');
var illegal = require('../rules/illegal');

/**
 * Conditional rule modifier:
 * The given rule only applies if the assertion evaluates to true. If the assertion evaluates to false,
 * the field will be "illegal" by default. Setting "elseRule" to "null" will instead allow any value
 * when the assertion evaluates to false. The assertion will be invoked with (value, fields).
 *
 * @param {Function} assertion
 * @param {*} rule The rule that applies if the assertion evaluates to true.
 * @param {*} [elseRule = function] The rule that applies if the assertion evaluates to false.
 *
 * @returns {function}
 */
module.exports = function (assertion, rule) {
    var elseRule = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : illegal;

    return function () {
        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return pTry(function () {
            return assertion.apply(undefined, args);
        }).then(function (result) {
            return result ? rule : elseRule;
        });
    };
};