'use strict';

/**
 * "Confirm" rule -- used to check if one field exactly
 * matches the value of another field
 * @param {string} referenceField
 * @param {Function} error
 * @param {boolean} [checkPresence = true] Throw an error if "referenceField" is not defined in the full payload
 * @returns {Function}
 */

module.exports = function (_ref) {
    var referenceField = _ref.referenceField,
        _ref$error = _ref.error,
        error = _ref$error === undefined ? function (field) {
        return 'Must be the same as "' + field + '"';
    } : _ref$error,
        _ref$checkPresence = _ref.checkPresence,
        checkPresence = _ref$checkPresence === undefined ? true : _ref$checkPresence;
    return function (value, otherValues) {

        if (!referenceField) return '"referenceField" undefined';
        if (checkPresence && !(referenceField in otherValues)) return '"' + referenceField + '" not defined in form fields';
        var reference = otherValues[referenceField];
        if (value !== reference) return error(referenceField);

        return null;
    };
};